@@ -4,17 +4,10 @@
 static char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #else
 #if defined(__NetBSD__) && defined(__IDSTRING)
-__IDSTRING(yyrcsid, "$NetBSD: skeleton.c,v 1.23 2002/01/31 21:01:15 tv Exp $");
+__IDSTRING(yyrcsid, "$NetBSD: skeleton.c,v 1.25 2003/08/07 11:17:54 agc Exp $");
 #endif /* __NetBSD__ && __IDSTRING */
 #endif /* 0 */
 #endif /* lint */
-#ifndef __P
-#ifdef __STDC__
-#define __P(x) x
-#else
-#define __P(x) ()
-#endif
-#endif
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
@@ -44,7 +37,7 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-#line 48 "fsi_gram.c"
+#line 41 "fsi_gram.c"
 #define tARCH 257
 #define tAS 258
 #define tAUTOMOUNT 259
@@ -309,10 +302,10 @@ short *yyss;
 short *yysslim;
 YYSTYPE *yyvs;
 int yystacksize;
-int yyparse __P((void));
+int yyparse(void);
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
-static int yygrowstack __P((void));
-static int yygrowstack __P((void))
+static int yygrowstack(void);
+static int yygrowstack(void)
 {
     int newsize, i;
     short *newss;
@@ -343,7 +336,7 @@ static int yygrowstack __P((void))
 #define YYACCEPT goto yyaccept
 #define YYERROR goto yyerrlab
 int
-yyparse __P((void))
+yyparse(void)
 {
     int yym, yyn, yystate;
 #if YYDEBUG
@@ -595,7 +588,7 @@ case 25:
 break;
 case 26:
 #line 236 "../../fsinfo/fsi_gram.y"
-{ yyval.d = (disk_fs *) NULL; }
+{ yyval.d = (disk_fs *) 0; }
 break;
 case 27:
 #line 252 "../../fsinfo/fsi_gram.y"
@@ -763,7 +756,7 @@ case 56:
 #line 417 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); }
 break;
-#line 767 "fsi_gram.c"
+#line 760 "fsi_gram.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
